@@ -592,12 +592,14 @@ cpu_attach(device_t parent, device_t dev, void *aux)
 	 */
 	if (CPU_ISSUN4V) {
 		paddr_t pa = ci->ci_paddr;
+		printf("ci->ci_paddr = %p\n", (void*)ci->ci_paddr);
 		int err;
 
 		pa += CPUINFO_VA - INTSTACK;
 		pa += PAGE_SIZE;
 
 		ci->ci_cpumq = pa;
+		printf("ci->ci_cpumq = %p\n", (void*)ci->ci_cpumq);
 		err = hv_cpu_qconf(CPU_MONDO_QUEUE, ci->ci_cpumq, SUN4V_MONDO_QUEUE_SIZE);
 		if (err != H_EOK)
 			panic("Unable to set cpu mondo queue: %d", err);
@@ -668,9 +670,10 @@ cpu_boot_secondary_processors(void)
 	}
 
 	for (ci = cpus; ci != NULL; ci = ci->ci_next) {
-		if (ci->ci_cpuid == cpu_myid())
+		if (ci->ci_cpuid == cpu_myid() || ci->ci_cpuid > 0)
 			continue;
-
+		
+		printf("pmap prepare cpuid %d\n", ci->ci_cpuid);
 		cpu_pmap_prepare(ci, false);
 		cpu_args->cb_node = ci->ci_node;
 		cpu_args->cb_cpuinfo = ci->ci_paddr;
@@ -681,18 +684,22 @@ cpu_boot_secondary_processors(void)
 		pstate = getpstate();
 		setpstate(PSTATE_KERN);
 
+		printf("Starting cpuid %d\n", ci->ci_cpuid);
 		int rc = prom_startcpu_by_cpuid(ci->ci_cpuid,
 		    (void *)cpu_spinup_trampoline, 0);
-		if (rc == -1)
+		if (rc == -1) {
+			printf("Starting cpuid the old way...%d\n", ci->ci_cpuid);
 			prom_startcpu(ci->ci_node,
 			    (void *)cpu_spinup_trampoline, 0);
-
+		}
 		for (i = 0; i < 2000; i++) {
+			printf("waiting %d\n", i);
 			membar_Sync();
 			if (CPUSET_HAS(cpus_active, ci->ci_index))
 				break;
 			delay(10000);
 		}
+		printf("waited\n");
 
 		/* synchronize %tick ( to some degree at least ) */
 		delay(1000);
@@ -704,11 +711,14 @@ cpu_boot_secondary_processors(void)
 			if (CPU_ISSUN4U || CPU_ISSUN4US)
 				setstick(0);
 
+		printf("setting pstate\n");
 		setpstate(pstate);
+		printf("setting pstate done\n");
 
 		if (!CPUSET_HAS(cpus_active, ci->ci_index))
 			printf("cpu%d: startup failed\n", ci->ci_cpuid);
 	}
+	printf("cpu started done\n");
 }
 
 void
